@@ -7,7 +7,7 @@ use Symbol qw(gensym);
 
 use vars qw[$SENDMAIL $VERSION];
 
-$VERSION   = '2.193';
+$VERSION   = '2.195';
 
 sub is_available {
     my $class = shift;
@@ -23,12 +23,17 @@ sub _find_sendmail {
     return $SENDMAIL if defined $SENDMAIL;
 
     my $sendmail;
-    for my $dir (File::Spec->path) {
+    for my $dir (
+      File::Spec->path,
+      File::Spec->catfile('', qw(usr sbin sendmail)),
+      File::Spec->catfile('', qw(usr lib sendmail)),
+    ) {
         if ( -x "$dir/sendmail" ) {
             $sendmail = "$dir/sendmail";
             last;
         }
     }
+
     return $sendmail;
 }
 
